@@ -27,6 +27,22 @@ class PangeaAPIException(PangeaException):
     def errors(self) -> List[ErrorField]:
         return self.response.errors
 
+    def __repr__(self) -> str:
+        ret = f"Summary: {self.response.summary}\n"
+        if self.response.errors:
+            ret += "Errors: \n"
+            for ef in self.response.errors:
+                ret += f"\t {ef.detail}\n"
+        return ret
+
+    def __str__(self) -> str:
+        ret = f"Summary: {self.response.summary}\n"
+        if self.response.errors:
+            ret += "Errors: \n"
+            for ef in self.response.errors:
+                ret += f"\t {ef.detail}\n"
+        return ret
+
 
 class ValidationException(PangeaAPIException):
     """Pangea Validation Errors denoting issues with an API request"""
@@ -48,6 +64,14 @@ class UnauthorizedException(PangeaAPIException):
         super(UnauthorizedException, self).__init__(message, response)
 
 
+class NotFound(PangeaAPIException):
+    """Resource not found"""
+
+    def __init__(self, url: str, response: PangeaResponse):
+        message = f"Resource {url} not found"
+        super(NotFound, self).__init__(message, response)
+
+
 class ServiceNotEnabledException(PangeaAPIException):
     def __init__(self, service_name: str, response: PangeaResponse):
         message = f"{service_name} is not enabled. Go to console.pangea.cloud/service/{service_name} to enable"
@@ -68,8 +92,12 @@ class ProviderErrorException(PangeaAPIException):
     """Downstream provider error"""
 
 
-class InternalServiceErrorException(PangeaAPIException):
-    """A pangea service error"""
+class InternalServerError(PangeaAPIException):
+    """A pangea server error"""
+
+    def __init__(self, response: PangeaResponse):
+        message = f"summary: {response.summary}. request_id: {response.request_id}. request_time: {response.request_time}. response_time: ${response.response_time}"
+        super().__init__(message, response)
 
 
 class ServiceNotAvailableException(PangeaAPIException):
@@ -95,3 +123,21 @@ class TreeNotFoundException(AuditAPIException):
 
 class BadOffsetException(AuditAPIException):
     """Bad offset in results search"""
+
+
+# Vault SDK specific exceptions
+class VaultException(PangeaException):
+    """Vault SDK specific exceptions"""
+
+
+# Vault API specific exceptions
+class VaultAPIException(PangeaAPIException):
+    """Vault service specific exceptions"""
+
+
+class ForbiddenVaultOperation(VaultAPIException):
+    """Forbiden Vault operation"""
+
+
+class VaultItemNotFound(VaultAPIException):
+    """Vault item not found"""
