@@ -1,9 +1,11 @@
 # Copyright 2022 Pangea Cyber Corporation
 # Author: Pangea Cyber Corporation
+import datetime
 import enum
 from typing import Any, Dict, Generic, List, Optional, TypeVar
 
 import requests
+from pangea.utils import format_datetime
 from pydantic import BaseModel
 
 T = TypeVar("T")
@@ -21,6 +23,9 @@ class APIResponseModel(BaseModel):
 class APIRequestModel(BaseModel):
     class Config:
         arbitrary_types_allowed = True
+        json_encoders = {
+            datetime.datetime: format_datetime,
+        }
 
 
 class PangeaResponseResult(APIResponseModel):
@@ -63,6 +68,10 @@ class ResponseStatus(str, enum.Enum):
     TREE_NOT_FOUND = "TreeNotFound"
     IP_NOT_FOUND = "IPNotFound"
     BAD_OFFSET = "BadOffset"
+    FORBIDDEN_VAULT_OPERATION = "ForbiddenVaultOperation"
+    VAULT_ITEM_NOT_FOUND = "VaultItemNotFound"
+    NOT_FOUND = "NotFound"
+    INTERNAL_SERVER_ERROR = "InternalError"
 
 
 class ResponseHeader(APIResponseModel):
